summaryrefslogtreecommitdiffstats
path: root/clib/hash.h
diff options
context:
space:
mode:
Diffstat (limited to 'clib/hash.h')
-rw-r--r--clib/hash.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/clib/hash.h b/clib/hash.h
index 52eb22f..29fd9ec 100644
--- a/clib/hash.h
+++ b/clib/hash.h
@@ -26,7 +26,7 @@
/*
* File: hash.h
* Author: Shaun Wetzstein <shaun@us.ibm.com>
* Descr: Various int32 hash functions
* Note:
* Date: 10/03/10
*/
@@ -38,13 +38,13 @@
/* ======================================================================= */
-static inline int32_t int32_hash1(int32_t);
+static inline int64_t int64_hash1(int64_t);
-typedef uint32_t(*hash_t) (char *, uint32_t);
+typedef uint64_t(*hash_t) (char *, uint64_t);
/* ======================================================================= */
-static inline int32_t int32_hash1(int32_t key)
+static inline int64_t int64_hash1(int64_t key)
{
key = ~key + (key << 15);
key = key ^ (key >> 12);
@@ -26,7 +26,7 @@
* File: hash.h
* Author: Shaun Wetzstein <shaun@us.ibm.com>
- * Descr: Various int32 hash functions
+ * Descr: Various int64 hash functions
* Note:
* Date: 10/03/10
OpenPOWER on IntegriCloud